@@ -7,7 +7,7 @@ static MunitSuite suites[] = {
     { NULL, NULL, NULL, 1, MUNIT_SUITE_OPTION_NONE }, \
     { NULL, NULL, NULL, 1, MUNIT_SUITE_OPTION_NONE }, \
     { NULL, NULL, NULL, 1, MUNIT_SUITE_OPTION_NONE },
-  #include "declare-suites.h"
+  #include <test/x86/declare-suites.h>
   #undef SIMDE_TEST_DECLARE_SUITE
   { NULL, NULL, NULL, 0, MUNIT_SUITE_OPTION_NONE },
   { NULL, NULL, NULL, 0, MUNIT_SUITE_OPTION_NONE }
@@ -24,7 +24,7 @@ simde_tests_x86_get_suite(void) {
     suites[i++] = *HEDLEY_CONCAT3(simde_test_x86_get_suite_, name, _native_cpp)(); \
     suites[i++] = *HEDLEY_CONCAT3(simde_test_x86_get_suite_, name, _emul_c)(); \
     suites[i++] = *HEDLEY_CONCAT3(simde_test_x86_get_suite_, name, _emul_cpp)();
-  #include "declare-suites.h"
+  #include <test/x86/declare-suites.h>
   #undef SIMDE_TEST_DECLARE_SUITE
   suites[i++] = *simde_tests_x86_avx512_get_suite();
 
